.. pyCSAMT documentation master file, created by
   sphinx-quickstart on Sun Feb 28 23:20:06 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyCSAMT's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   csamt
   processing
   modeling 
   geocore 
   geodb
   utils
   viewer

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
